Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(325)

Unified Diff: webrtc/modules/audio_coding/neteq/expand.h

Issue 1925053002: Revert of Avoiding overflow in cross correlation in NetEq. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/modules/audio_coding/neteq/cross_correlation.cc ('k') | webrtc/modules/audio_coding/neteq/expand.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/audio_coding/neteq/expand.h
diff --git a/webrtc/modules/audio_coding/neteq/expand.h b/webrtc/modules/audio_coding/neteq/expand.h
index 44ced0ab6c21e34c2fa502a81f01402cdcfb2a7a..7f61bf3b18c3217bd4406a515267f2b1327b5b96 100644
--- a/webrtc/modules/audio_coding/neteq/expand.h
+++ b/webrtc/modules/audio_coding/neteq/expand.h
@@ -120,10 +120,12 @@
// Calculate the auto-correlation of |input|, with length |input_length|
// samples. The correlation is calculated from a downsampled version of
// |input|, and is written to |output|.
void Correlation(const int16_t* input,
size_t input_length,
- int16_t* output) const;
+ int16_t* output,
+ int* output_scale) const;
void UpdateLagIndex();
« no previous file with comments | « webrtc/modules/audio_coding/neteq/cross_correlation.cc ('k') | webrtc/modules/audio_coding/neteq/expand.cc » ('j') | no next file with comments »
@@ -120,10 +120,12 @@
// Calculate the auto-correlation of |input|, with length |input_length|
// samples. The correlation is calculated from a downsampled version of
- // |input|, and is written to |output|.
+ // |input|, and is written to |output|. The scale factor is written to
+ // |output_scale|.
void Correlation(const int16_t* input,
size_t input_length,

Powered by Google App Engine
This is Rietveld 408576698